==> apache-inlong-1.3.0-src.tar.gz: apache-inlong-1.3.0/inlong-dataproxy/dataproxy-source/src/main/java/org/apache/inlong/dataproxy/base/ProxyMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.dataproxy.base;

import java.util.Map;

import org.apache.inlong.dataproxy.consts.AttributeConstants;

public class ProxyMessage {

    private String groupId;
    private String topic;
    private String streamId;

    private Map<String, String> attributeMap;

    private byte[] data;

    public ProxyMessage(String groupId, String streamId, Map<String, String> attributeMap, byte[] data) {
        this.groupId = groupId;
        this.streamId = streamId;
        this.attributeMap = attributeMap;
        this.data = data;
    }

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
        this.attributeMap.put(AttributeConstants.GROUP_ID, groupId);
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getStreamId() {
        return streamId;
    }

    public void setStreamId(String streamId) {
        this.streamId = streamId;
        this.attributeMap.put(AttributeConstants.STREAM_ID, streamId);
    }

    public Map<String, String> getAttributeMap() {
        return attributeMap;
    }

    public void setAttributeMap(Map<String, String> attributeMap) {
        this.attributeMap = attributeMap;
    }

    public byte[] getData() {
        return data;
    }

    public void setData(byte[] data) {
        this.data = data;
    }
}

==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-dataproxy/dataproxy-source/src/main/java/org/apache/inlong/dataproxy/base/ProxyMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.dataproxy.base;

import java.util.Map;
import org.apache.inlong.common.msg.AttributeConstants;

public class ProxyMessage {

    private String groupId;
    private String topic;
    private String streamId;

    private Map<String, String> attributeMap;

    private byte[] data;

    public ProxyMessage(String groupId, String streamId, Map<String, String> attributeMap, byte[] data) {
        this.groupId = groupId;
        this.streamId = streamId;
        this.attributeMap = attributeMap;
        this.data = data;
    }

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
        this.attributeMap.put(AttributeConstants.GROUP_ID, groupId);
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getStreamId() {
        return streamId;
    }

    public void setStreamId(String streamId) {
        this.streamId = streamId;
        this.attributeMap.put(AttributeConstants.STREAM_ID, streamId);
    }

    public Map<String, String> getAttributeMap() {
        return attributeMap;
    }

    public void setAttributeMap(Map<String, String> attributeMap) {
        this.attributeMap = attributeMap;
    }

    public byte[] getData() {
        return data;
    }

    public void setData(byte[] data) {
        this.data = data;
    }
}
